@@ -44,13 +44,14 @@ except NameError:
 
 # Where do we get up-to-date seeds from?
 SEEDS = "http://people.ubuntu.com/~cjwatson/seeds/"
-RELEASE = "edgy"
+SEEDS_BZR = "http://bazaar.launchpad.net/~ubuntu-core-dev/ubuntu-seeds/"
+RELEASE = "ubuntu.feisty"
 
 # If we need to download Packages.gz and/or Sources.gz, where do we get
 # them from?
 MIRROR = "http://archive.ubuntu.com/ubuntu/"
 SOURCE_MIRROR = None
-DIST = ["edgy"]
+DIST = ["feisty"]
 COMPONENTS = ["main", "restricted"]
 ARCH = "i386"
 
@@ -242,6 +243,11 @@ def write_prov_list(filename, provdict):
         print >>f
     f.close()
 
+def write_structure(filename, structure):
+    f = open(filename, "w")
+    print >>f, structure,
+    f.close()
+
 
 def usage(f):
     print >>f, """Usage: germinate.py [options]
@@ -274,13 +280,14 @@ Options:
 
 
 def main():
-    global SEEDS, RELEASE, MIRROR, SOURCE_MIRROR
+    global SEEDS, SEEDS_BZR, RELEASE, MIRROR, SOURCE_MIRROR
     global DIST, ARCH, COMPONENTS, CHECK_IPV6
     verbose = False
     bzr = False
     cleanup = False
     want_rdepends = True
     seed_packages = ()
+    seeds_set = False
 
     g = Germinator()
 
@@ -314,6 +321,7 @@ def main():
             SEEDS = value
             if not SEEDS.endswith("/"):
                 SEEDS += "/"
+            seeds_set = True
         elif option in ("-s", "--seed-dist"):
             RELEASE = value
         elif option in ("-m", "--mirror"):
@@ -334,6 +342,8 @@ def main():
             CHECK_IPV6 = True
         elif option == "--bzr":
             bzr = True
+            if not seeds_set:
+                SEEDS = SEEDS_BZR
         elif option == "--cleanup":
             cleanup = True
         elif option == "--no-rdepends":
@@ -446,6 +456,8 @@ def main():
 
     write_prov_list("provides", g.pkgprovides)
 
+    write_structure("structure", g.structure)
+
     if os.path.exists("rdepends"):
         shutil.rmtree("rdepends")
     if want_rdepends:
