@@ -30,9 +30,9 @@ import Germinate.seeds
 
 # TODO: cloned from germinate.py; should be common
 SEEDS = "http://people.ubuntu.com/~cjwatson/seeds/"
-RELEASE = "edgy"
+RELEASE = "ubuntu.feisty"
 MIRROR = "http://archive.ubuntu.com/ubuntu/"
-DIST = ["edgy"]
+DIST = ["feisty"]
 COMPONENTS = ["main"]
 ARCH = "i386"
 
